@@ -1,10 +1,10 @@
 #import <objectbase/SwarmObject.h>
 #import <defobj/Create.h>
 #import <defobj/defalloc.h>
-#import "AsciiMemLogger.h"
-#import "KISSMemLogger.h"
-#import "RMemLogger.h"
-#import "MemLogConsumer.h"
+#import <logzone/AsciiMemLogger.h>
+#import <logzone/KISSMemLogger.h>
+#import <logzone/RMemLogger.h>
+#import <logzone/MemLogConsumer.h>
 
 @interface LoggingZone : SwarmObject
 {
